@@ -20,8 +20,8 @@ from beakerx.utils import *
 from beakerx.plot.plotitem import *
 from beakerx.plot.plotitem_treemap import *
 from enum import Enum
-from ipywidgets import DOMWidget, register
 from traitlets import Unicode, Dict
+from beakerx.beakerx_widgets import BeakerxDOMWidget
 
 
 class Chart(BaseObject):
@@ -36,6 +36,7 @@ class Chart(BaseObject):
                                         LegendPosition())
         self.legend_layout = getValue(kwargs, 'legendLayout',
                                       LegendLayout.VERTICAL)
+        self.type = "Plot"
 
 
 class AbstractChart(Chart):
@@ -78,14 +79,14 @@ class XYChart(AbstractChart):
     def add(self, item):
         if isinstance(item, YAxis):
             self.rangeAxes.append(item)
-        elif isinstance(item, Graphics):
-            self.graphics_list.append(item)
         elif isinstance(item, Text):
             self.texts.append(item)
         elif isinstance(item, ConstantLine):
             self.constant_lines.append(item)
         elif isinstance(item, ConstantBand):
             self.constant_bands.append(item)
+        elif isinstance(item, Graphics):
+            self.graphics_list.append(item)
         elif isinstance(item, list):
             for elem in item:
                 self.add(elem)
@@ -189,11 +190,9 @@ class CombinedChart(BaseObject):
         self.plot_type = 'Plot'
 
 
-class Plot(DOMWidget):
+class Plot(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
     _model_name = Unicode('PlotModel').tag(sync=True)
-    _view_module = Unicode('beakerx').tag(sync=True)
-    _model_module = Unicode('beakerx').tag(sync=True)
     model = Dict().tag(sync=True)
     
     def __init__(self, **kwargs):
@@ -210,7 +209,7 @@ class Plot(DOMWidget):
         return self.chart.rangeAxes
 
 
-class CategoryPlot(DOMWidget):
+class CategoryPlot(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
     _model_name = Unicode('PlotModel').tag(sync=True)
     _view_module = Unicode('beakerx').tag(sync=True)
@@ -228,7 +227,7 @@ class CategoryPlot(DOMWidget):
         return self
 
 
-class HeatMap(DOMWidget):
+class HeatMap(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
     _model_name = Unicode('PlotModel').tag(sync=True)
     _view_module = Unicode('beakerx').tag(sync=True)
@@ -266,7 +265,7 @@ class HeatMap(DOMWidget):
         self.model = self.chart.transform()
 
 
-class Histogram(DOMWidget):
+class Histogram(BeakerxDOMWidget):
     class DisplayMode(Enum):
         OVERLAP = 1
         STACK = 2
@@ -290,7 +289,7 @@ class Histogram(DOMWidget):
         self.model = self.chart.transform()
 
 
-class TreeMap(DOMWidget):
+class TreeMap(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
     _model_name = Unicode('PlotModel').tag(sync=True)
     _view_module = Unicode('beakerx').tag(sync=True)
@@ -377,7 +376,7 @@ class SimpleTimePlot(TimePlot):
             if tableData.index.name is not None:
                 time_column_default = tableData.index.name
             tableData = tableData.to_dict(orient='rows')
-            
+        
         timeColumn = getValue(kwargs, 'timeColumn', time_column_default)
         if tableData is not None and columnNames is not None:
             dataColumnsNames.extend(list(tableData[0]))
@@ -425,7 +424,7 @@ class SimpleTimePlot(TimePlot):
                     self.add(points)
 
 
-class CombinedPlot(DOMWidget):
+class CombinedPlot(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
     _model_name = Unicode('PlotModel').tag(sync=True)
     _view_module = Unicode('beakerx').tag(sync=True)
